@@ -43,52 +43,52 @@ class Table(QGraphicsScene):
         computer = ComputerRandom(self)
         self.players.append(computer)
 
+        """
+        self.fields[1][1].starting(True)
+        self.fields[1][2].starting(False)
+        self.fields[2][1].starting(False)
+        self.fields[2][2].starting(True)
 
-        #self.fields[1][1].starting(True)
-        #self.fields[1][2].starting(False)
-        #self.fields[2][1].starting(False)
-        #self.fields[2][2].starting(True)
+        self.fields[1][0].starting(True)
 
-        #self.fields[1][0].starting(True)
+        self.fields[2][1].starting(True)
 
-        #self.fields[2][1].starting(True)
+        self.fields[2][2].starting(False)
+        self.fields[3][2].starting(True)
+        self.fields[4][2].starting(True)
 
-        #self.fields[2][2].starting(False)
-        #self.fields[3][2].starting(True)
-        #self.fields[4][2].starting(True)
+        self.fields[0][3].starting(True)
+        self.fields[2][3].starting(True)
+        self.fields[3][3].starting(True)
+        self.fields[4][3].starting(True)
+        self.fields[5][3].starting(True)
 
-        #self.fields[0][3].starting(True)
-        #self.fields[2][3].starting(True)
-        #self.fields[3][3].starting(True)
-        #self.fields[4][3].starting(True)
-        #self.fields[5][3].starting(True)
+        self.fields[0][4].starting(True)
+        self.fields[1][4].starting(True)
+        self.fields[2][4].starting(True)
+        self.fields[3][4].starting(True)
+        self.fields[4][4].starting(True)
+        self.fields[5][4].starting(True)
+        self.fields[6][4].starting(True)
 
-        #self.fields[0][4].starting(True)
-        #self.fields[1][4].starting(True)
-        #self.fields[2][4].starting(True)
-        #self.fields[3][4].starting(True)
-        #self.fields[4][4].starting(True)
-        #self.fields[5][4].starting(True)
-        #self.fields[6][4].starting(True)
+        self.fields[0][5].starting(False)
+        self.fields[1][5].starting(True)
+        self.fields[2][5].starting(True)
+        self.fields[3][5].starting(False)
+        self.fields[4][5].starting(True)
+        self.fields[7][5].starting(True)
 
-        #self.fields[0][5].starting(False)
-        #self.fields[1][5].starting(True)
-        #self.fields[2][5].starting(True)
-        #self.fields[3][5].starting(False)
-        #self.fields[4][5].starting(True)
-        #self.fields[7][5].starting(True)
-
-        #self.fields[0][6].starting(False)
-        #self.fields[1][6].starting(False)
-        #self.fields[2][6].starting(True)
-        #self.fields[3][6].starting(True)
-        #self.fields[4][6].starting(True)
-        #self.fields[7][6].starting(True)
-
-        #self.fields[0][7].starting(False)
-        #self.fields[1][7].starting(False)
-        #self.fields[2][7].starting(False)
+        self.fields[0][6].starting(False)
+        self.fields[1][6].starting(False)
+        self.fields[2][6].starting(True)
+        self.fields[3][6].starting(True)
+        self.fields[4][6].starting(True)
+        self.fields[7][6].starting(True)
 
+        self.fields[0][7].starting(False)
+        self.fields[1][7].starting(False)
+        self.fields[2][7].starting(False)
+        """
         #for i in range(0, 8):
         #    for j in range(0, 8):
         #        if (i == 2 and j == 2) or (i == 4 and j == 4): continue
@@ -112,6 +112,8 @@ class Table(QGraphicsScene):
         self._calculatePossibleMoves()
         self.player = False
         self.players[int(self.player)].activate()
+        self.emit(SIGNAL('setScores'), [2, 2])
+        self.hitstory = []
         #print self.moves
 
     def _calculatePossibleMoves(self):
@@ -169,6 +171,7 @@ class Table(QGraphicsScene):
         #f.write('\n')
         #f.close()
         #self.history.append(self.moves['%s-%s' % (x, y)])
+        self.history.append([self.player, x, y])
         self.fields[x][y].set(self.player)
         for tx, ty in self.moves['%s-%s' % (x, y)][1]:
             self.fields[tx][ty].set(self.player)
@@ -192,20 +195,23 @@ class Table(QGraphicsScene):
         self.players[int(self.player)].deactivate()
         self.player = True if not self.player else False
         self._calculatePossibleMoves()
+        #print self.moves
         self.players[int(self.player)].activate()
         if not self.moves: self.nextPlayer()
-        #print self.moves
 
     def getPosibleMoves(self):
         return self.moves
 
-    #def saveHistory(self):
-    #    f = open('moves.txt', 'w')
-    #    for i in range(0, 8):
-    #        for j in range(0, 8):
-    #            if self.fields[i][j].get() != None:
-    #                f.write('self.fields[%s][%s].starting(%s)\n' % (i, j, self.fields[i][j].get()))
-    #    f.close()
+    def saveHistory(self, file):
+        import os
+        dir = os.path.dirname(file)
+        if not os.path.exists(dir):
+            os.makedirs(dir)
+
+        f = open(file, 'w')
+        f.write(str(self.history))
+        f.close()
+        return True
 
     #def makeMove(self):
     #    self.players[int(self.player)].activate()
